##  Benefits
  * Enhanced data quality: The aggregation and linkage feature improves inventory quality and eliminates any data redundancy by automatically aggregating multiple ServiceNow asset versions (and removing irrelevant ones) into consolidated fact sheets linked to the reference catalog. During synchronization with ServiceNow, up to one million of ServiceNow records can be aggregated.
  * Streamlined setup of your software inventory: This feature streamlines the setup and management of your software inventory by aggregating similar items, eliminating the need to manually screen through all versions, patches, and updates to decide which ones should be synced.
  * Lifecycle information from the reference catalog for obsolescence risk management: Automatic linking to the reference catalog allows you to get relevant vendor lifecycle information for accurate obsolescence risk management. Any updates to the catalog data automatically appear on linked fact sheets, eliminating the need for manual updates and enhancing data quality. To learn how to manage obsolescence risk in SAP LeanIX, see [Obsolescence Risk Management](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management?locale=en-US&state=PRODUCTION&version=CLOUD "Learn why obsolescence risk management matters, how to discover risks associated with obsolete technology, how to assess their business impact, and how to efficiently manage and address them with SAP LeanIX.").
